Exception: DataShifter::ExternalRequestNotAllowedError
- Inherits:
-
StandardError
- Object
- StandardError
- DataShifter::ExternalRequestNotAllowedError
- Defined in:
- lib/data_shifter/errors.rb
Overview
Raised when a dry run attempts an outbound HTTP request to a host that is not allowed via allow_external_requests (per-shift or global config).
Instance Attribute Summary collapse
-
#attempted_host ⇒ Object
readonly
Returns the value of attribute attempted_host.
Instance Method Summary collapse
-
#initialize(attempted_host: nil) ⇒ ExternalRequestNotAllowedError
constructor
A new instance of ExternalRequestNotAllowedError.
Constructor Details
#initialize(attempted_host: nil) ⇒ ExternalRequestNotAllowedError
Returns a new instance of ExternalRequestNotAllowedError.
7 8 9 10 |
# File 'lib/data_shifter/errors.rb', line 7 def initialize(attempted_host: nil) @attempted_host = attempted_host super() end |
Instance Attribute Details
#attempted_host ⇒ Object (readonly)
Returns the value of attribute attempted_host.
12 13 14 |
# File 'lib/data_shifter/errors.rb', line 12 def attempted_host @attempted_host end |